@@ -1,6 +1,6 @@
 package AnyEvent::Beanstalk;
 {
-  $AnyEvent::Beanstalk::VERSION = '1.121460';
+  $AnyEvent::Beanstalk::VERSION = '1.123530';
 }
 
 use strict;
@@ -118,6 +118,7 @@ my %EXPECT = qw(
   peek-delayed         FOUND
   peek-buried          FOUND
   kick                 KICKED
+  kick-job             KICKED
   stats-job            OK
   stats-tube           OK
   stats                OK
@@ -316,6 +317,7 @@ sub watch_only {
       foreach my $t (@$tubes) {
         $tubes{$t} = 0 unless delete $tubes{$t};
       }
+      $done->() if !keys %tubes;
       foreach my $t (sort { $tubes{$b} <=> $tubes{$a} } keys %tubes) {
         my $cmd = $tubes{$t} ? 'watch' : 'ignore';
         $self->run_cmd(
@@ -393,6 +395,13 @@ sub kick {
 }
 
 
+sub kick_job {
+  my $self  = shift;
+  my @cb    = (@_ and ref($_[-1]) eq 'CODE') ? splice(@_, -1) : ();
+  my $id    = shift || 0;
+  $self->run_cmd('kick-job' => $id, @cb);
+}
+
 sub use {
   my $self = shift;
   my @cb   = (@_ and ref($_[-1]) eq 'CODE') ? splice(@_, -1) : ();
@@ -587,7 +596,7 @@ AnyEvent::Beanstalk - Async client to talk to beanstalkd server
 
 =head1 VERSION
 
-version 1.121460
+version 1.123530
 
 =head1 SYNOPSIS
 
@@ -920,6 +929,10 @@ jobs.
 
 The response value is the number of jobs kicked
 
+=item B<kick_job ($id, [$callback])>
+
+Kick the specified job C<$id>.
+
 =item B<stats_job ($id, [$callback])>
 
 Return stats for the specified job C<$id>.
